import request from '@/config/axios'

// 充值套餐 VO
export interface ComboVO {
  id: number // 编号
  name: string // 套餐名称
  rechargeAmount: number // 充值金额
  shopBonus: number // 店铺赠送金额
  profitRatio: number // 微股东分润比例
  tierProfitRatio: number // 分层利润比
}

// 充值套餐 API
export const ComboApi = {
  // 查询充值套餐分页
  getComboPage: async (params: any) => {
    return await request.get({ url: `/member/combo/page`, params })
  },

  // 查询充值套餐详情
  getCombo: async (id: number) => {
    return await request.get({ url: `/member/combo/get?id=` + id })
  },

  // 新增充值套餐
  createCombo: async (data: ComboVO) => {
    return await request.post({ url: `/member/combo/create`, data })
  },

  // 修改充值套餐
  updateCombo: async (data: ComboVO) => {
    return await request.put({ url: `/member/combo/update`, data })
  },

  // 删除充值套餐
  deleteCombo: async (id: number) => {
    return await request.delete({ url: `/member/combo/delete?id=` + id })
  },

  // 导出充值套餐 Excel
  exportCombo: async (params) => {
    return await request.download({ url: `/member/combo/export-excel`, params })
  },

// ==================== 子表（会员等级） ====================

  // 获得会员等级分页
  getLevelPage: async (params) => {
    return await request.get({ url: `/member/combo/level/page`, params })
  },
  // 新增会员等级
  createLevel: async (data) => {
    return await request.post({ url: `/member/combo/level/create`, data })
  },

  // 修改会员等级
  updateLevel: async (data) => {
    return await request.put({ url: `/member/combo/level/update`, data })
  },

  // 删除会员等级
  deleteLevel: async (id: number) => {
    return await request.delete({ url: `/member/combo/level/delete?id=` + id })
  },

  // 获得会员等级
  getLevel: async (id: number) => {
    return await request.get({ url: `/member/combo/level/get?id=` + id })
  }
}