import request from '@/config/axios'

// 会员等级 VO
export interface LevelVO {
  id: number // 编号
  name: string // 等级名称
  level: number // 等级
  experience: number // 升级经验
  discountPercent: number // 享受折扣
  icon: string // 等级图标
  backgroundUrl: string // 等级背景图
  status: number // 状态
  comboId: number // 所属套餐
}

// 会员等级 API
export const LevelApi = {
  // 查询会员等级分页
  getLevelPage: async (params: any) => {
    return await request.get({ url: `/member/level/page`, params })
  },

  // 查询会员等级详情
  getLevel: async (id: number) => {
    return await request.get({ url: `/member/level/get?id=` + id })
  },

  // 新增会员等级
  createLevel: async (data: LevelVO) => {
    return await request.post({ url: `/member/level/create`, data })
  },

  // 修改会员等级
  updateLevel: async (data: LevelVO) => {
    return await request.put({ url: `/member/level/update`, data })
  },

  // 删除会员等级
  deleteLevel: async (id: number) => {
    return await request.delete({ url: `/member/level/delete?id=` + id })
  },

  // 导出会员等级 Excel
  exportLevel: async (params) => {
    return await request.download({ url: `/member/level/export-excel`, params })
  }
}