import request from '@/config/axios'

// 交易记录 VO
export interface TradeVO {
  id: number // 编号
  rechargeId: number // 充值用户id
  rechargeNickname: string // 充值用户昵称
  rechargeComboId: number // 充值套餐id
  rechargeComboName: string // 充值套餐名称
  rechargeLevelId: number // 充值用户等级id
  rechargeLevelName: string // 充值用户等级
  rechargeMoney: number // 用户充值金额
  shopGiveMoney: number // 店家赠送金额
  centsId: number // 分润用户ID
  centsNickname: string // 分润用户昵称
  centsLevelId: number // 分润用户等级id
  centsLevelName: string // 分润用户等级
  centsLostMoney: number // 分润金额
  platformRate: number // 平台费率
  platformMoney: number // 平台金额
}

// 交易记录 API
export const TradeApi = {
  // 查询交易记录分页
  getTradePage: async (params: any) => {
    return await request.get({ url: `/member/trade/page`, params })
  },

  // 查询交易记录详情
  getTrade: async (id: number) => {
    return await request.get({ url: `/member/trade/get?id=` + id })
  },

  // 新增交易记录
  createTrade: async (data: TradeVO) => {
    return await request.post({ url: `/member/trade/create`, data })
  },

  // 修改交易记录
  updateTrade: async (data: TradeVO) => {
    return await request.put({ url: `/member/trade/update`, data })
  },

  // 删除交易记录
  deleteTrade: async (id: number) => {
    return await request.delete({ url: `/member/trade/delete?id=` + id })
  },

  // 导出交易记录 Excel
  exportTrade: async (params) => {
    return await request.download({ url: `/member/trade/export-excel`, params })
  }
}